@@ -1,7 +1,8 @@
 """JSON Serialization"""
 
 from decimal import Decimal
-from inspect import Parameter
+from enum import Enum
+from inspect import Parameter, isclass
 import json
 from typing import (
     Any,
@@ -13,11 +14,12 @@ from typing import (
     cast
 )
 
-import jetblack_serialization.typing_inspect_ex as typing_inspect
+from .. import typing_inspect_ex as typing_inspect
 from ..config import SerializerConfig
+from ..custom_annotations import get_typed_dict_key_default
 from ..types import Annotation
-
 from ..utils import is_simple_type
+
 from .annotations import (
     JSONAnnotation,
     JSONValue,
@@ -46,6 +48,8 @@ def _to_value(
             return float(value)
         elif type_annotation is Decimal:
             return Decimal(value)
+        elif isclass(type_annotation) and issubclass(type_annotation, Enum):
+            return type_annotation[value]
         else:
             deserializer = config.value_deserializers.get(type_annotation)
             if deserializer is not None:
@@ -132,8 +136,8 @@ def _to_dict(
 
     typed_dict_keys = typing_inspect.typed_dict_keys(dict_annotation)
     for key, key_annotation in typed_dict_keys.items():
-        default = getattr(dict_annotation, key, Parameter.empty)
-        if typing_inspect.is_annotated_type(key_annotation):
+        default = get_typed_dict_key_default(key_annotation)
+        if is_json_annotation(key_annotation):
             item_type_annotation, item_json_annotation = get_json_annotation(
                 key_annotation
             )
@@ -145,7 +149,9 @@ def _to_dict(
                 key
             ) if isinstance(key, str) else key
             json_property = JSONProperty(tag)
-            item_type_annotation = key_annotation
+            item_type_annotation = typing_inspect.get_unannotated_type(
+                key_annotation
+            )
 
         if json_property.tag in obj:
             json_obj[key] = _to_any(
@@ -221,7 +227,7 @@ def from_json_value(
     """Convert from a json value
 
     Args:
-        config (SerializerConfig): The serialier configuration
+        config (SerializerConfig): The serializer configuration
         json_value (Any): The JSON value
         annotation (Annotation): The type annotation
 
@@ -248,7 +254,7 @@ def from_json_value(
     )
 
 
-def deserialize(
+def deserialize_typed(
         text: str,
         annotation: Annotation,
         config: SerializerConfig
